This is the mail archive of the
gcc-patches@gcc.gnu.org
mailing list for the GCC project.
Re: Small patch: new regset_head typedef
- To: gcc-patches at gcc dot gnu dot org
- Subject: Re: Small patch: new regset_head typedef
- From: Bernd Schmidt <bernds at cygnus dot co dot uk>
- Date: Mon, 22 Nov 1999 11:59:28 +0000 (GMT)
> * basic-block.h (regset_head): New typedef.
It turns out they also want to be initialized and there's no macro for that
yet either. :-/
Bernd
* basic-block.h (regset_head): New typedef.
(INIT_REG_SET): New macro.
Index: basic-block.h
===================================================================
RCS file: /cvs/gcc/egcs/gcc/basic-block.h,v
retrieving revision 1.41
diff -u -p -r1.41 basic-block.h
--- basic-block.h 1999/11/18 08:00:50 1.41
+++ basic-block.h 1999/11/22 11:54:15
@@ -23,7 +23,13 @@ Boston, MA 02111-1307, USA. */
#include "sbitmap.h"
#include "varray.h"
-typedef bitmap regset; /* Head of register set linked list. */
+/* Head of register set linked list. */
+typedef bitmap_head regset_head;
+/* A pointer to a regset_head. */
+typedef bitmap regset;
+
+/* Initialize a new regset. */
+#define INIT_REG_SET(HEAD) bitmap_initialize (HEAD)
/* Clear a register set by freeing up the linked list. */
#define CLEAR_REG_SET(HEAD) bitmap_clear (HEAD)